@@ -36,7 +36,12 @@ pub struct EmoteMapper {
 }
 
 impl Default for EmoteMapper {
-    fn default() -> Self { Self { map: Default::default(), emote_width: 3 } }
+    fn default() -> Self {
+        Self {
+            map: Default::default(),
+            emote_width: 3,
+        }
+    }
 }
 
 impl EmoteMapper {
@@ -49,11 +54,14 @@ impl EmoteMapper {
     }
 
     /// Returns the char representing the `emote_name`
-    pub fn to_char(&self, emote_name: &str) -> Option<char> { self.map.get(emote_name).copied().map(char::from) }
+    pub fn to_char(&self, emote_name: &str) -> Option<char> {
+        self.map.get(emote_name).copied().map(char::from)
+    }
 
     /// Returns a string with the char representing the `emote_name` padded to `emte_width`
     pub fn to_string(&self, emote_name: &str) -> Option<String> {
-        self.to_char(emote_name).map(|c| format!("{}{}", c, " ".repeat(self.emote_width - 1)))
+        self.to_char(emote_name)
+            .map(|c| format!("{}{}", c, " ".repeat(self.emote_width - 1)))
     }
 
     /// Replaces all emotes in the `message` given
@@ -64,7 +72,8 @@ impl EmoteMapper {
         }
 
         RE.replace_all(message, |w: &Captures| {
-            self.to_string(w.get(0).unwrap().as_str()).unwrap_or_else(|| w.get(0).unwrap().as_str().to_owned())
+            self.to_string(w.get(0).unwrap().as_str())
+                .unwrap_or_else(|| w.get(0).unwrap().as_str().to_owned())
         })
     }
 }
@@ -73,7 +82,10 @@ impl EmoteMapper {
 impl EmoteMapper {
     /// Creates an EmoteMapper from a Reader containing csv data
     pub fn from_reader(rdr: impl Read) -> Result<Self, EmoteMapperError> {
-        let mut rdr = csv::ReaderBuilder::new().has_headers(false).trim(Trim::All).from_reader(rdr);
+        let mut rdr = csv::ReaderBuilder::new()
+            .has_headers(false)
+            .trim(Trim::All)
+            .from_reader(rdr);
 
         let map = rdr
             .deserialize::<Mapping>()
@@ -82,25 +94,34 @@ impl EmoteMapper {
                 Ok((r.name, r.code_point))
             })
             .collect::<Result<_, EmoteMapperError>>()?;
-        Ok(EmoteMapper { map, ..EmoteMapper::default() })
+        Ok(EmoteMapper {
+            map,
+            ..EmoteMapper::default()
+        })
     }
 
     /// Creates an EmoteMapper from a File containing csv data
-    pub fn from_path(p: &Path) -> Result<Self, EmoteMapperError> { Self::from_reader(File::open(p).map_err(IOError)?) }
+    pub fn from_path<P: AsRef<Path>>(p: P) -> Result<Self, EmoteMapperError> {
+        Self::from_reader(File::open(p).map_err(IOError)?)
+    }
 }
 
 impl FromStr for EmoteMapper {
     type Err = EmoteMapperError;
 
     /// Creates an EmoteMapper from a String containing csv data
-    fn from_str(s: &str) -> Result<Self, Self::Err> { Self::from_reader(s.as_bytes()) }
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        Self::from_reader(s.as_bytes())
+    }
 }
 
 /// Saving
 impl EmoteMapper {
     /// Writes the EmoteMapper as csv to a Writer
     pub fn to_writer(self, wtr: impl Write) -> Result<(), EmoteMapperError> {
-        let mut wtr = csv::WriterBuilder::new().has_headers(false).from_writer(wtr);
+        let mut wtr = csv::WriterBuilder::new()
+            .has_headers(false)
+            .from_writer(wtr);
         for mapping in self.map.into_iter().map(Mapping::from) {
             wtr.serialize(mapping).unwrap();
         }
@@ -108,7 +129,9 @@ impl EmoteMapper {
     }
 
     /// Stores the EmoteMapper as csv in a File
-    pub fn to_path(self, p: &Path) -> Result<(), EmoteMapperError> { self.to_writer(File::open(p).map_err(IOError)?) }
+    pub fn to_path(self, p: &Path) -> Result<(), EmoteMapperError> {
+        self.to_writer(File::open(p).map_err(IOError)?)
+    }
 }
 
 impl From<EmoteMapper> for String {
@@ -116,7 +139,8 @@ impl From<EmoteMapper> for String {
     fn from(val: EmoteMapper) -> Self {
         let mut s = "".to_string();
         {
-            val.to_writer(unsafe { s.as_mut_vec() }).expect("Writing to String should not fail");
+            val.to_writer(unsafe { s.as_mut_vec() })
+                .expect("Writing to String should not fail");
         }
         s
     }
@@ -139,7 +163,9 @@ struct Mapping {
 }
 
 impl From<(String, CodePoint)> for Mapping {
-    fn from((name, code_point): (String, CodePoint)) -> Self { Mapping { name, code_point } }
+    fn from((name, code_point): (String, CodePoint)) -> Self {
+        Mapping { name, code_point }
+    }
 }
 
 #[derive(Error, Debug)]
@@ -157,15 +183,21 @@ pub enum EmoteMapperError {
 struct CodePoint(char);
 
 impl From<CodePoint> for char {
-    fn from(cp: CodePoint) -> Self { cp.0 }
+    fn from(cp: CodePoint) -> Self {
+        cp.0
+    }
 }
 
 impl Display for CodePoint {
-    fn fmt(&self, f: &mut __private::Formatter<'_>) -> std::fmt::Result { char::from(*self).fmt(f) }
+    fn fmt(&self, f: &mut __private::Formatter<'_>) -> std::fmt::Result {
+        char::from(*self).fmt(f)
+    }
 }
 
 impl From<CodePoint> for String {
-    fn from(val: CodePoint) -> Self { format!("{:X}", val.0 as u32) }
+    fn from(val: CodePoint) -> Self {
+        format!("{:X}", val.0 as u32)
+    }
 }
 
 impl TryFrom<String> for CodePoint {
@@ -173,8 +205,10 @@ impl TryFrom<String> for CodePoint {
 
     fn try_from(s: String) -> Result<Self, Self::Error> {
         Ok(CodePoint(
-            char::from_u32(u32::from_str_radix(&s, 16).map_err(|_| InvalidCodepoint(s.to_string()))?)
-                .ok_or_else(|| InvalidCodepoint(s.to_string()))?,
+            char::from_u32(
+                u32::from_str_radix(&s, 16).map_err(|_| InvalidCodepoint(s.to_string()))?,
+            )
+            .ok_or_else(|| InvalidCodepoint(s.to_string()))?,
         ))
     }
 }
